@@ -2,6 +2,6 @@ utils::globalVariables(
   c(
     ".", ".N", "reg", "link_id", "seq_count", "seq_freq", "V1", "V2",
     "from", "from_count", "to", "to_prob", "conditional_prob",
-    "relative_risk", "%>%", "everything", "desc"
+    "relative_risk", "%>%", "everything", "desc",".data", "med.from", "med.to"
   )
 )
